﻿//-----------------------------------------------------------------------------
// <copyright file="MMM8x8.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2014 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>Constants for MMM8x8 device communication.</summary>
//-----------------------------------------------------------------------------
namespace MMM8x8Utils
{
    using System.IO.Ports;

    /// <summary>
    /// Constants for MMM8x8 device communication.
    /// </summary>
    public static class MMM8x8
    {
        /// <summary>
        /// Baud option for MMM8x8 device communication.
        /// </summary>
        public static readonly int BaudRate = 38400;

        /// <summary>
        /// Parity option for MMM8x8 device communication.
        /// </summary>
        public static readonly Parity Parity = Parity.None;

        /// <summary>
        /// Databits option for MMM8x8 device communication.
        /// </summary>
        public static readonly int Databits = 8;

        /// <summary>
        /// Stop bits option for MMM8x8 device communication.
        /// </summary>
        public static readonly StopBits StopBits = StopBits.One;

        /// <summary>
        /// Read timeout in ms for MMM8x8 device communication.
        /// </summary>
        public static readonly int ReadTimeout = 500;

        /// <summary>
        /// Write timeout in ms for MMM8x8 device communication.
        /// </summary>
        public static readonly int WriteTimeout = 500;

        /// <summary>
        /// Pause in ms between reading and writing.
        /// </summary>
        public static readonly int WaitBetweenWriteAndRead = 50;

        /// <summary>
        /// Enumeration of possible commands for the MMM8x8.
        /// </summary>
        public enum Commands
        {
            /// <summary>
            /// Activates the preview mode.
            /// </summary>
            SetPreviewModeCommand = 'B',

            /// <summary>
            /// Sets all leds.
            /// </summary>
            SetAllLedsCommand = 'D'
        }
    }
}
